'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var repositoryProvider = require('repository-provider');

class MockBranch extends repositoryProvider.Branch {
  async content(path, options = {}) {
    if (this.files[path] === undefined) {
      if (options.ignoreMissing) {
        return '';
      }
      return undefined;
    }

    return this.files[path];
  }

  get files() {
    return this.repository.files[this.name];
  }
}

class MockRepository extends repositoryProvider.Repository {
  get files() {
    return this.provider.files[this.name];
  }

  async initialize() {
    await super.initialize();
    await Promise.all(
      Object.keys(this.files).map(branchName => this.createBranch(branchName))
    );
  }
}

/**
 * @param {Object} files
 */
class MockProvider extends repositoryProvider.Provider {
  constructor(files) {
    super();
    Object.defineProperty(this, 'files', {
      value: files
    });
  }

  async initialize() {
    return Promise.all(
      Object.keys(this.files).map(repoName => this.createRepository(repoName))
    );
  }

  get branchClass() {
    return MockBranch;
  }

  get repositoryClass() {
    return MockRepository;
  }
}

exports.MockBranch = MockBranch;
exports.MockRepository = MockRepository;
exports.MockProvider = MockProvider;
